==> PhysX-4.0.0.zip: PhysX-4.0.0/physx/documentation/PhysXAPI/files/classPxSimulationStatistics.js <==
var classPxSimulationStatistics =
[
    [ "RbPairStatsType", "classPxSimulationStatistics.html#a56865c878c5d74dd30a7ab81e2728c36", [
      [ "eDISCRETE_CONTACT_PAIRS", "classPxSimulationStatistics.html#a56865c878c5d74dd30a7ab81e2728c36a366eae507d69961741d28c3b6c04d576", null ],
      [ "eCCD_PAIRS", "classPxSimulationStatistics.html#a56865c878c5d74dd30a7ab81e2728c36a13b4e0a4ca71ad756078820ab928c1b3", null ],
      [ "eMODIFIED_CONTACT_PAIRS", "classPxSimulationStatistics.html#a56865c878c5d74dd30a7ab81e2728c36ae1d23646a3bd6d7cfef7986a92afe270", null ],
      [ "eTRIGGER_PAIRS", "classPxSimulationStatistics.html#a56865c878c5d74dd30a7ab81e2728c36a9b0bca86a9a15f66d11b191efbcfb65b", null ]
    ] ],
    [ "PxSimulationStatistics", "classPxSimulationStatistics.html#a910e1921a55acda66f5c22ee173eda32", null ],
    [ "getNbBroadPhaseAdds", "classPxSimulationStatistics.html#adcb848b8642fd2bfbc21d589de6a81b6", null ],
    [ "getNbBroadPhaseRemoves", "classPxSimulationStatistics.html#a5918fad96b0c2c876f333deacb7661c1", null ],
    [ "getRbPairStats", "classPxSimulationStatistics.html#a4412ac46b492100c5a8446ba3ba35164", null ],
    [ "compressedContactSize", "classPxSimulationStatistics.html#abfacb597d8b72b1d86961dfdb8e768e3", null ],
    [ "nbActiveConstraints", "classPxSimulationStatistics.html#a3ba1901c4ac662c535daa1ac58987aba", null ],
    [ "nbActiveDynamicBodies", "classPxSimulationStatistics.html#adb8e7d0a9d70b16a4b7309c4d47685e2", null ],
    [ "nbActiveKinematicBodies", "classPxSimulationStatistics.html#af783cd541d93f5f72b64f07cebbbe71a", null ],
    [ "nbAggregates", "classPxSimulationStatistics.html#a4903606cb701b7237a92a6a43f8d60ea", null ],
    [ "nbArticulations", "classPxSimulationStatistics.html#abfd24df0bcef58fccc82cd06423aeff2", null ],
    [ "nbAxisSolverConstraints", "classPxSimulationStatistics.html#a9b03e0dc11df05eea8ded2e95d01fdcf", null ],
    [ "nbBroadPhaseAdds", "classPxSimulationStatistics.html#a832a4823ac63af2716b4132aad10b51c", null ],
    [ "nbBroadPhaseRemoves", "classPxSimulationStatistics.html#ac086bc02b779c42c0b38f09c2fde294b", null ],
    [ "nbCCDPairs", "classPxSimulationStatistics.html#a3a3e17aed5223a69ba3b832f909a6a59", null ],
    [ "nbDiscreteContactPairs", "classPxSimulationStatistics.html#a97dfe63f126e504699c8eeda86ebcb28", null ],
    [ "nbDiscreteContactPairsTotal", "classPxSimulationStatistics.html#a6310732fffde7fa5013aada6ca2434c1", null ],
    [ "nbDiscreteContactPairsWithCacheHits", "classPxSimulationStatistics.html#afc4203ee9a309b63e0a9638595d28867", null ],
    [ "nbDiscreteContactPairsWithContacts", "classPxSimulationStatistics.html#a897bc3a4b6dc809b1f04059fe4b4a2af", null ],
    [ "nbDynamicBodies", "classPxSimulationStatistics.html#a1d5feb904597a5a98d02f39707e6c349", null ],
    [ "nbLostPairs", "classPxSimulationStatistics.html#a84b14e904af17d9c86d158ecea5fb9d1", null ],
    [ "nbLostTouches", "classPxSimulationStatistics.html#ae20e0fabfd1e8dfdec622a496bfbaf83", null ],
    [ "nbModifiedContactPairs", "classPxSimulationStatistics.html#aade3e5f9699bfd0858786f9ed6b7d1c9", null ],
    [ "nbNewPairs", "classPxSimulationStatistics.html#a717bce9ff3da25dd9250c1746008e52b", null ],
    [ "nbNewTouches", "classPxSimulationStatistics.html#a612d72aad0d4e7adab3bbb5f14135bf1", null ],
    [ "nbPartitions", "classPxSimulationStatistics.html#aab9b2646eb89d7fb3bb707256be46cf0", null ],
    [ "nbShapes", "classPxSimulationStatistics.html#a2385b3afe6fc6237f7fcbb4712e4ad57", null ],
    [ "nbStaticBodies", "classPxSimulationStatistics.html#a8aebb151f3f50cd831f2a42165ef9409", null ],
    [ "nbTriggerPairs", "classPxSimulationStatistics.html#abcb6c70a6d7e5146767b0be74db34cde", null ],
    [ "peakConstraintMemory", "classPxSimulationStatistics.html#ab56ac5aa68f31b68a0852c87817ff026", null ],
    [ "requiredContactConstraintMemory", "classPxSimulationStatistics.html#aa1e487295538b16ec29c359082d12976", null ]
];

==> PhysX-4.1.zip: PhysX-4.1/physx/documentation/PhysXAPI/files/classPxSimulationStatistics.js <==
var classPxSimulationStatistics =
[
    [ "RbPairStatsType", "classPxSimulationStatistics.html#a56865c878c5d74dd30a7ab81e2728c36", [
      [ "eDISCRETE_CONTACT_PAIRS", "classPxSimulationStatistics.html#a56865c878c5d74dd30a7ab81e2728c36a366eae507d69961741d28c3b6c04d576", null ],
      [ "eCCD_PAIRS", "classPxSimulationStatistics.html#a56865c878c5d74dd30a7ab81e2728c36a13b4e0a4ca71ad756078820ab928c1b3", null ],
      [ "eMODIFIED_CONTACT_PAIRS", "classPxSimulationStatistics.html#a56865c878c5d74dd30a7ab81e2728c36ae1d23646a3bd6d7cfef7986a92afe270", null ],
      [ "eTRIGGER_PAIRS", "classPxSimulationStatistics.html#a56865c878c5d74dd30a7ab81e2728c36a9b0bca86a9a15f66d11b191efbcfb65b", null ]
    ] ],
    [ "PxSimulationStatistics", "classPxSimulationStatistics.html#a910e1921a55acda66f5c22ee173eda32", null ],
    [ "getNbBroadPhaseAdds", "classPxSimulationStatistics.html#adcb848b8642fd2bfbc21d589de6a81b6", null ],
    [ "getNbBroadPhaseRemoves", "classPxSimulationStatistics.html#a5918fad96b0c2c876f333deacb7661c1", null ],
    [ "getRbPairStats", "classPxSimulationStatistics.html#a4412ac46b492100c5a8446ba3ba35164", null ],
    [ "compressedContactSize", "classPxSimulationStatistics.html#abfacb597d8b72b1d86961dfdb8e768e3", null ],
    [ "nbActiveConstraints", "classPxSimulationStatistics.html#a3ba1901c4ac662c535daa1ac58987aba", null ],
    [ "nbActiveDynamicBodies", "classPxSimulationStatistics.html#adb8e7d0a9d70b16a4b7309c4d47685e2", null ],
    [ "nbActiveKinematicBodies", "classPxSimulationStatistics.html#af783cd541d93f5f72b64f07cebbbe71a", null ],
    [ "nbAggregates", "classPxSimulationStatistics.html#a4903606cb701b7237a92a6a43f8d60ea", null ],
    [ "nbArticulations", "classPxSimulationStatistics.html#abfd24df0bcef58fccc82cd06423aeff2", null ],
    [ "nbAxisSolverConstraints", "classPxSimulationStatistics.html#a9b03e0dc11df05eea8ded2e95d01fdcf", null ],
    [ "nbBroadPhaseAdds", "classPxSimulationStatistics.html#a832a4823ac63af2716b4132aad10b51c", null ],
    [ "nbBroadPhaseRemoves", "classPxSimulationStatistics.html#ac086bc02b779c42c0b38f09c2fde294b", null ],
    [ "nbCCDPairs", "classPxSimulationStatistics.html#a3a3e17aed5223a69ba3b832f909a6a59", null ],
    [ "nbDiscreteContactPairs", "classPxSimulationStatistics.html#a97dfe63f126e504699c8eeda86ebcb28", null ],
    [ "nbDiscreteContactPairsTotal", "classPxSimulationStatistics.html#a6310732fffde7fa5013aada6ca2434c1", null ],
    [ "nbDiscreteContactPairsWithCacheHits", "classPxSimulationStatistics.html#afc4203ee9a309b63e0a9638595d28867", null ],
    [ "nbDiscreteContactPairsWithContacts", "classPxSimulationStatistics.html#a897bc3a4b6dc809b1f04059fe4b4a2af", null ],
    [ "nbDynamicBodies", "classPxSimulationStatistics.html#a1d5feb904597a5a98d02f39707e6c349", null ],
    [ "nbKinematicBodies", "classPxSimulationStatistics.html#a38012209b56e1e6993e0955f3a5606d2", null ],
    [ "nbLostPairs", "classPxSimulationStatistics.html#a84b14e904af17d9c86d158ecea5fb9d1", null ],
    [ "nbLostTouches", "classPxSimulationStatistics.html#ae20e0fabfd1e8dfdec622a496bfbaf83", null ],
    [ "nbModifiedContactPairs", "classPxSimulationStatistics.html#aade3e5f9699bfd0858786f9ed6b7d1c9", null ],
    [ "nbNewPairs", "classPxSimulationStatistics.html#a717bce9ff3da25dd9250c1746008e52b", null ],
    [ "nbNewTouches", "classPxSimulationStatistics.html#a612d72aad0d4e7adab3bbb5f14135bf1", null ],
    [ "nbPartitions", "classPxSimulationStatistics.html#aab9b2646eb89d7fb3bb707256be46cf0", null ],
    [ "nbShapes", "classPxSimulationStatistics.html#a2385b3afe6fc6237f7fcbb4712e4ad57", null ],
    [ "nbStaticBodies", "classPxSimulationStatistics.html#a8aebb151f3f50cd831f2a42165ef9409", null ],
    [ "nbTriggerPairs", "classPxSimulationStatistics.html#abcb6c70a6d7e5146767b0be74db34cde", null ],
    [ "peakConstraintMemory", "classPxSimulationStatistics.html#ab56ac5aa68f31b68a0852c87817ff026", null ],
    [ "requiredContactConstraintMemory", "classPxSimulationStatistics.html#aa1e487295538b16ec29c359082d12976", null ]
];
